mean_score
==============================================

.. currentmodule:: skchange.scores

.. autofunction:: mean_score

.. include:: skchange.scores.mean_score.examples

.. raw:: html

    <div class="clearer"></div>